=======
History
=======

0.1.0 (2018-02-02)
------------------

* First release on PyPI.

0.1.5 (2018-03-12)
------------------

* New governing equations
* Tests for uniform axial mean flow
* New API + documentation

